@@ -20,24 +20,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/** 
- * SeahorseContext: This is where all the action in a Seahorse process comes
- * together. 
- *
- * - Usually there's only one SeahorseContext per process created by passing 
- *   |SEAHORSE_CONTEXT_APP| to |seahorse_context_new|, and accessed via 
- *   the |SCTX_APP| macro.
- * - Retains the list of all valid struct _SeahorseObject objects. 
- * - Has a collection of SeahorseSource objects which add objects to the 
- *   SeahorseContext. 
- * 
- * Signals:
- *   added: A object was added to the context.
- *   removed: A object was removed from the context.
- *   changed: A object changed.
- *   destroy: The context was destroyed.
- */
- 
 #ifndef __SEAHORSE_CONTEXT_H__
 #define __SEAHORSE_CONTEXT_H__
 
@@ -61,19 +43,41 @@ typedef struct _SeahorseContext SeahorseContext;
 typedef struct _SeahorseContextClass SeahorseContextClass;
 typedef struct _SeahorseContextPrivate SeahorseContextPrivate;
 
+/**
+ * SeahorseContext:
+ * @parent: The parent #GtkObject
+ * @is_daemon: a #gboolean indicating whether the context is being used in a
+ *             program that is daemonized
+ *
+ * This is where all the action in a Seahorse process comes together.
+ *
+ * - Usually there's only one #SeahorseContext per process created by passing
+ *   %SEAHORSE_CONTEXT_APP to seahorse_context_new(), and accessed via
+ *   the %SCTX_APP macro.
+ * - Retains the list of all valid struct _SeahorseObject objects.
+ * - Has a collection of #SeahorseSource objects which add objects to the
+ *   #SeahorseContext.
+ *
+ * Signals:
+ *   added: A object was added to the context.
+ *   removed: A object was removed from the context.
+ *   changed: A object changed.
+ *   destroy: The context was destroyed.
+ */
+
 struct _SeahorseContext {
-    GtkObject               parent;
-    
-    /*< public >*/
-    gboolean                is_daemon;
-    
-    /*< private >*/
-    SeahorseContextPrivate  *pv;
+	GObject parent;
+
+	/*< public >*/
+	gboolean is_daemon;
+
+	/*< private >*/
+	SeahorseContextPrivate  *pv;
 };
 
 struct _SeahorseContextClass {
-    GtkObjectClass parent_class;
-    
+	GObjectClass parent_class;
+
     /* signals --------------------------------------------------------- */
     
     /* A object was added to this source */
@@ -87,22 +91,19 @@ struct _SeahorseContextClass {
     
     /* The source is being refreshed */
     void (*refreshing) (SeahorseContext *sctx, SeahorseOperation *op);
-};
 
-enum SeahorseContextType {
-    SEAHORSE_CONTEXT_APP = 1,
-    SEAHORSE_CONTEXT_DAEMON = 2,
+	void (*destroy) (SeahorseContext *sctx);
 };
 
 typedef void (*SeahorseObjectFunc) (struct _SeahorseObject *obj, gpointer user_data);
 
-#define             SCTX_APP()                          (seahorse_context_for_app ())
+#define             SCTX_APP()                          (seahorse_context_instance ())
 
 GType               seahorse_context_get_type           (void);
 
-SeahorseContext*    seahorse_context_for_app            (void);
+SeahorseContext*    seahorse_context_instance           (void);
 
-SeahorseContext*    seahorse_context_new                (guint              flags);
+void                seahorse_context_create             (void);
 
 void                seahorse_context_destroy            (SeahorseContext    *sctx);
 
@@ -188,16 +189,6 @@ GList*              seahorse_context_discover_objects   (SeahorseContext    *sct
                                                          GQuark             ktype, 
                                                          GSList             *ids);
 
-struct _SeahorseObject*     seahorse_context_object_from_dbus   (SeahorseContext    *sctx,
-                                                         const gchar        *dbusid);
-
-gchar*              seahorse_context_object_to_dbus     (SeahorseContext    *sctx,
-                                                         struct _SeahorseObject *sobj);
-
-gchar*              seahorse_context_id_to_dbus         (SeahorseContext    *sctx,
-                                                         GQuark             id);
-
-
 typedef GQuark (*SeahorseCanonizeFunc) (const gchar *id);
 
 GQuark              seahorse_context_canonize_id        (GQuark ktype, const gchar *id);
