@@ -28,9 +28,13 @@
 #include <gconf/gconf-client.h>
 
 #include <gtk/gtk.h>
-#include "cryptui-defines.h"
 
-#define ARMOR_KEY SEAHORSE_DESKTOP_KEYS "/ascii_armor"
+#define SEAHORSE_DESKTOP_KEYS           "/desktop/pgp"
+#define SEAHORSE_DEFAULT_KEY            SEAHORSE_DESKTOP_KEYS "/default_key"
+#define SEAHORSE_LASTSIGNER_KEY         SEAHORSE_DESKTOP_KEYS "/last_signer"
+#define SEAHORSE_ENCRYPTSELF_KEY        SEAHORSE_DESKTOP_KEYS "/encrypt_to_self"
+#define SEAHORSE_RECIPIENTS_SORT_KEY    SEAHORSE_DESKTOP_KEYS "/recipients/sort_by"
+
 #define ENCRYPTSELF_KEY SEAHORSE_DESKTOP_KEYS "/encrypt_to_self"
 #define MULTI_EXTENSION_KEY SEAHORSE_DESKTOP_KEYS "/package_extension"
 #define MULTI_SEPERATE_KEY SEAHORSE_DESKTOP_KEYS "/multi_seperate"
@@ -43,7 +47,7 @@
 
 #define SEAHORSE_SCHEMAS            "/apps/seahorse"
 
-#define KEYSHARING_KEY              SEAHORSE_SCHEMAS "/sharing/sharing_enabled"
+#define WINDOW_SIZE                SEAHORSE_SCHEMAS "/windows/"
 
 void            seahorse_gconf_disconnect        ();
 
