@@ -69,7 +69,7 @@ on_pgp_generate_key (GtkAction *action, gpointer unused)
 	
 	g_return_if_fail (GTK_IS_ACTION (action));
 	
-	sksrc = seahorse_context_find_source (seahorse_context_for_app (), SEAHORSE_PGP_TYPE, SEAHORSE_LOCATION_LOCAL);
+	sksrc = seahorse_context_find_source (seahorse_context_instance (), SEAHORSE_PGP_TYPE, SEAHORSE_LOCATION_LOCAL);
 	g_return_if_fail (sksrc != NULL);
 	
 	seahorse_gpgme_generate_show (SEAHORSE_GPGME_SOURCE (sksrc), NULL, NULL, NULL, NULL);
@@ -436,15 +436,9 @@ seahorse_gpgme_generate_show (SeahorseGpgmeSource *sksrc, GtkWindow *parent, con
     /* The algoritms */
     widget = seahorse_widget_get_widget (swidget, "algorithm-choice");
     g_return_if_fail (widget != NULL);
-#if GTK_CHECK_VERSION (2,91,2)
     gtk_combo_box_text_remove (GTK_COMBO_BOX_TEXT (widget), 0);
     for(i = 0; i < G_N_ELEMENTS(available_algorithms); i++)
         gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (widget), _(available_algorithms[i].desc));
-#else
-    gtk_combo_box_remove_text (GTK_COMBO_BOX (widget), 0);
-    for(i = 0; i < G_N_ELEMENTS(available_algorithms); i++)
-        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _(available_algorithms[i].desc));
-#endif
     gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
     on_gpgme_generate_algorithm_changed (GTK_COMBO_BOX (widget), swidget);
     
