@@ -149,6 +149,7 @@ on_app_about (GtkAction* action, SeahorseViewer* self)
 	gtk_about_dialog_set_website_label (about, _("Seahorse Project Homepage"));
 	
 	g_signal_connect (about, "response", G_CALLBACK (gtk_widget_hide), NULL);
+	gtk_window_set_transient_for (GTK_WINDOW (about), seahorse_viewer_get_window (self));
 	
 	gtk_dialog_run (GTK_DIALOG (about));
 	gtk_widget_destroy (GTK_WIDGET (about));
@@ -479,7 +480,7 @@ on_key_import_keyring (GtkAction* action, SeahorseViewer* self)
 	if (objects == NULL) 
 		return;
 
-	op = seahorse_context_transfer_objects (seahorse_context_for_app (), objects, NULL);
+	op = seahorse_context_transfer_objects (seahorse_context_instance (), objects, NULL);
 	seahorse_progress_show (op, _ ("Importing keys from key servers"), TRUE);
 	seahorse_operation_watch (op, (SeahorseDoneFunc)imported_keys, self, NULL, NULL);
 	
