@@ -61,9 +61,8 @@
 
 enum {
     PROP_0,
-    PROP_KEY_TYPE,
-    PROP_KEY_DESC,
-    PROP_LOCATION,
+    PROP_SOURCE_TAG,
+    PROP_SOURCE_LOCATION,
     PROP_BASE_DIRECTORY
 };
 
@@ -609,13 +608,10 @@ seahorse_ssh_source_get_property (GObject *object, guint prop_id, GValue *value,
     SeahorseSSHSource *ssrc = SEAHORSE_SSH_SOURCE (object);
     
     switch (prop_id) {
-    case PROP_KEY_TYPE:
+    case PROP_SOURCE_TAG:
         g_value_set_uint (value, SEAHORSE_SSH);
         break;
-    case PROP_KEY_DESC:
-        g_value_set_string (value, _("Secure Shell Key"));
-        break;
-    case PROP_LOCATION:
+    case PROP_SOURCE_LOCATION:
         g_value_set_enum (value, SEAHORSE_LOCATION_LOCAL);
         break;
     case PROP_BASE_DIRECTORY:
@@ -703,9 +699,8 @@ seahorse_ssh_source_class_init (SeahorseSSHSourceClass *klass)
     gobject_class->set_property = seahorse_ssh_source_set_property;
     gobject_class->get_property = seahorse_ssh_source_get_property;
     
-	g_object_class_override_property (gobject_class, PROP_KEY_TYPE, "key-type");
-	g_object_class_override_property (gobject_class, PROP_KEY_DESC, "key-desc");
-	g_object_class_override_property (gobject_class, PROP_LOCATION, "location");
+	g_object_class_override_property (gobject_class, PROP_SOURCE_TAG, "source-tag");
+	g_object_class_override_property (gobject_class, PROP_SOURCE_LOCATION, "source-location");
 
     g_object_class_install_property (gobject_class, PROP_BASE_DIRECTORY,
         g_param_spec_string ("base-directory", "Key directory", "Directory where the keys are stored",
